<?php
namespace JHodges\Sitemap;

use GuzzleHttp\Exception\RequestException;
use GuzzleHttp\RequestOptions;
use GuzzleHttp\Psr7\Uri;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\UriInterface;

use Spatie\Crawler\Crawler as SpatieCrawler;
use Spatie\Crawler\CrawlUrl;
use Spatie\Crawler\CrawlAllUrls;
use Spatie\Crawler\CrawlProfile;

class Crawler{

    private $observer;
    private $crawler;

    public function __construct(array $reqOps=[]){
        $this->crawler = SpatieCrawler::create(array_merge($reqOps, [
            RequestOptions::ALLOW_REDIRECTS => [
                'track_redirects' => true,
            ],
        ]));

        $this->observer = new CrawlObserver();
        $this->crawler->setCrawlObserver($this->observer);
        $this->crawler->setCrawlProfile(new CrawlAllUrls());
    }

    public function setUserAgent(String $agent) : self{
        $this->crawler->setUserAgent($agent);
	return $this;
    }

    public function setCrawlProfile(CrawlProfile $p) : self{
        $this->crawler->setCrawlProfile($p);
	return $this;
    }

    public function crawl(String $url) : void{
        $this->crawler->startCrawling($url);
    }

    public function getResults() : array{
        return $this->observer->results;
    }

}
